import React, { useState } from 'react';
import { SnackbarContent, Snackbar, Grid } from '@mui/material';
import CloseIcon from '@mui/icons-material/Close';
import { useNavigate } from 'react-router-dom';
import { makeStyles } from 'tss-react/mui';
import alert_error from '../assets/img/alert_error.svg';
import alert_success from '../assets/img/alert_success.svg';
import alert_warning from '../assets/img/alert_warning.svg';
const useStyles = makeStyles()((_theme) => {
    return {
        body: {
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'space-between',
        },
        message: {
            width: '100%',
            fontSize: '14px',
        },
        text_warning: {
            color: '#FFB919',
            fontSize: '14px',
        },
        text_error: {
            color: '#FF4E4E',
            fontSize: '14px',
        },
        text_success: {
            color: '#02AB83',
        },
        body_warning: {
            background: '#FFF6E2',
            boxShadow: 'none',
        },
        body_error: {
            background: '#FFEDED',
            boxShadow: 'none',
        },
        body_success: {
            background: '#D9FFEE',
            boxShadow: 'none',
        },
    };
});

const variantIcon = {
    success: alert_success,
    warning: alert_warning,
    error: alert_error,
};

export default () => {
    const { classes } = useStyles();
    const navigate = useNavigate();
    const [onloading, setOnloading] = useState(false);
    const [messages, setMessages] = useState<{
        message: string;
        messagetype: 'success' | 'warning' | 'error';
    }>({
        message: '',
        messagetype: 'success',
    });

    const Icon = variantIcon[messages.messagetype];

    const handleClose = (_e: any) => {
        setMessages(() => {
            return {
                message: '',
                messagetype: 'success',
            };
        });
    };

    const render = (dom: any) => {
        return (
            <React.Fragment>
                {dom}
                <Snackbar
                    anchorOrigin={{
                        vertical: 'top',
                        horizontal: 'center',
                    }}
                    sx={{ maxWidth: '380px', margin: '0 auto' }}
                    autoHideDuration={3000}
                    open={messages['message'] ? true : false}
                    onClose={handleClose}
                    key={messages['message']}
                >
                    <SnackbarContent
                        message={
                            <Grid className={classes.body}>
                                <Grid
                                    sx={{
                                        display: 'flex',
                                        alignItems: 'center',
                                    }}
                                >
                                    <img
                                        src={Icon}
                                        style={{ marginRight: '10px' }}
                                    />
                                    <Grid
                                        className={
                                            classes[
                                                `text_${messages.messagetype}`
                                            ]
                                        }
                                    >
                                        {messages['message']}
                                    </Grid>
                                </Grid>

                                <CloseIcon
                                    fontSize="small"
                                    className={
                                        classes[`text_${messages.messagetype}`]
                                    }
                                />
                            </Grid>
                        }
                        classes={{
                            root: classes[`body_${messages.messagetype}`],
                            message: classes.message,
                        }}
                    />
                </Snackbar>
            </React.Fragment>
        );
    };

    return { render, navigate, setMessages, setOnloading };
};
